/*************************************************************************
 *
 *    Used with ICCARM and AARM.
 *
 *    (c) Copyright IAR Systems 2007
 *
 *    File name   : main.c
 *    Description : CAN test
 *
 *    History :
 *    1. Date        : April 28, 2007
 *       Author      : Stanimir Bonev
 *       Description : Create
 *
 *    $Revision: 1.4 $
 **************************************************************************/
// #include <stdio.h>

#include "stm32f10x_lib.h"
#include "arm_comm.h"
#include "lcd.h"
#include "adc.h"
#include "stm32f10x_map.h"
#include "bits.h"
#include "nRF24L01.h"
#include "const.h"
#include "drv_lisxxx.h"


#define KEY_NONE    0
#define KEY_UP      1
#define KEY_DOWN    2
#define KEY_LEFT    3
#define KEY_RIGHT   4
#define KEY_CENTER  5

#define UP_VALUE        960
#define DOWN_VALUE      190
#define LEFT_VALUE     1990
#define RIGHT_VALUE     470
#define DIVERSION        30


__root __no_init volatile RCC_TypeDef     ttt1 @ RCC_BASE;
__root __no_init volatile GPIO_TypeDef    ttt2 @ GPIOB_BASE;
__root __no_init volatile AFIO_TypeDef    ttt3 @ AFIO_BASE;
__root __no_init volatile I2C_TypeDef     ttt4 @ I2C1_BASE;


unsigned char ch=0, index=0, flag=0;
unsigned char config, status_temp, payload;
extern unsigned char status;
extern GPIO_InitTypeDef GPIO_InitStructure;
volatile unsigned int dly;
Int16U ADCValue;
unsigned char jjj=0;

unsigned char JoyPos;
unsigned char buf;
unsigned char b;
void Delay_ (unsigned long a) { while (--a!=0); }
unsigned char config, dummy, var, payload;
unsigned int i=0;

/*************************************************************************
 * Function Name: Clk_Init
 * Parameters: Int32U Frequency
 * Return: Int32U
 *
 * Description: Init clock system
 *
 *************************************************************************/
void Clk_Init(void)
{
  // 1. Cloking the controller from internal HSI RC (8 MHz)
  RCC_HSICmd(ENABLE);
  // wait until the HSI is ready
  while(RCC_GetFlagStatus(RCC_FLAG_HSIRDY) == RESET);
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);
  // 2. Enable ext. high frequency OSC
  RCC_HSEConfig(RCC_HSE_ON);
  // wait until the HSE is ready
  while(RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET);
  // 3. Init PLL
  RCC_PLLConfig(RCC_PLLSource_HSE_Div1,RCC_PLLMul_9); // 72MHz
//  RCC_PLLConfig(RCC_PLLSource_HSE_Div2,RCC_PLLMul_9); // 72MHz
  RCC_PLLCmd(ENABLE);
  // wait until the PLL is ready
  while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
  // 4. Set system clock divders
  RCC_USBCLKConfig(RCC_USBCLKSource_PLLCLK_1Div5);
  RCC_ADCCLKConfig(RCC_PCLK2_Div8);
  RCC_PCLK2Config(RCC_HCLK_Div1);
  RCC_PCLK1Config(RCC_HCLK_Div2);
  RCC_HCLKConfig(RCC_SYSCLK_Div1);
  /* Flash 1 wait state */
  *(vu32 *)0x40022000 = 0x01;
  // 5. Clock system from PLL
  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
}


/*************************************************************************
 * Function Name: InitJoystick
 * Parameters: none
 * Return: none
 *
 * Description: Init joystick position
 *
 *************************************************************************/
void InitJoystick(void) {

  // Set variables asociates
  JoyPos = 0;
    // Init
  ADCInit();
  // BUTTON CENTER as input
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  // B1 as input
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_13;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

}
/*************************************************************************
 * Function Name: GetJoystickPosition
 * Parameters: none
 * Return: Joistick position
 *
 * Description: Measure ADC and return joystick position
 *
 *************************************************************************/
unsigned char GetJoystickPosition (void) {

  ADCValue = GetADCChanel(ADC_Channel_15);

  if( (ADCValue>(UP_VALUE-DIVERSION))&&(ADCValue<(UP_VALUE+DIVERSION)) )       { return KEY_UP; }
  if( (ADCValue>(DOWN_VALUE-DIVERSION))&&(ADCValue<(DOWN_VALUE+DIVERSION)) )   { return KEY_DOWN; }
  if( (ADCValue>(LEFT_VALUE-DIVERSION))&&(ADCValue<(LEFT_VALUE+DIVERSION)) )   { return KEY_LEFT; }
  if( (ADCValue>(RIGHT_VALUE-DIVERSION))&&(ADCValue<(RIGHT_VALUE+DIVERSION)) ) { return KEY_RIGHT; }

  if((GPIO_ReadInputDataBit(GPIOC, GPIO_Pin_6)) == Bit_SET) return KEY_CENTER;

  return KEY_NONE;

}


/*************************************************************************
 * Function Name: main
 * Parameters: none
 * Return: Int32U
 *
 * Description: The main subroutine
 *
 *************************************************************************/
/*NOTE:After first message displayed on screen, press WAKEUP button as written 
on dispay, then press joystick in any direction. Consequently it will be displayed on screen,
if its code succesfully sent back from other board acting as echo-server.
If you want try again, press RESET to reset board, and follow as written above.
*/
int main(void)
{

  #ifdef DEBUG
    debug();
  #endif

  // Init clock system
  Clk_Init();

  // LCD init
  LCDInit();
  LCDContrast(0x45);

  LCDClear();
  LCDStr ( 0, "   Welcome to ", 0 );
  LCDStr ( 1, " STM32F103-STK", 0 );
  LCDStr ( 2, "  development ", 0 );
  LCDStr ( 3, "     board    ", 0 );
  LCDStr ( 5, "www.olimex.com", 1 );
  LCDUpdate();

  // Delay :-)
  for(dly=0; dly<5000000; dly++);

// Test NRF ------------------------------------------------------------------
  

    LCDClear();
    LCDStr ( 0, "   Test NRF   ", 0 );
    LCDStr ( 1, " press WAKE-UP", 0 );
    LCDStr ( 2, " send/receive ", 0 );
    LCDStr ( 3, "   one byte   ", 0 );
    LCDUpdate();
    //wait for WAKEUP to be pressed
    while(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)==Bit_RESET);

        // RESET LCD
    GPIO_WriteBit(GPIOC, GPIO_Pin_10, Bit_SET);

    nRFSetting();
     // Init joystick
    InitJoystick();
     
    // B1 as input
    GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_13;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
    GPIO_Init(GPIOC, &GPIO_InitStructure);

    while(1) {
      // Check joystick position
      JoyPos = GetJoystickPosition();
     
      if(JoyPos==KEY_UP) { buf=KEY_UP;            }

      if(JoyPos==KEY_DOWN) { buf=KEY_DOWN;       }

      if(JoyPos==KEY_LEFT) { buf=KEY_LEFT;       }

      if(JoyPos==KEY_RIGHT){ buf=KEY_RIGHT;       }

      if(JoyPos==KEY_CENTER) {buf=KEY_CENTER;     }
    
   
      
      if (JoyPos!=KEY_NONE) 
          {  

                    // Send joystick position byte  -------------------------------------------------
                
                    // Chip enable low
                    CE_LOW();
                
                    // Setting for TX device
                    // Write CONFIG register -> 00001010 - CRC enable, power-up, TX
                    status = SPI_Send_command_with_ADDR(W_REGISTER,CONFIG_REG_ADDR, 0x0A);
                
                    // Send payload - send any data
                    status = SPI_Send_command_without_ADDR(W_TX_PAYLOAD, buf);
                
                    // Pulse for CE -> starts the transmission.
                    CE_HIGH();
                    CE_LOW();
                
                    // Read STATUS register
                    status = SPI_Send_command_without_ADDR(NOP, NOP);
                
                    // if exceed number of transmision packets
                    if ((status & MAX_RT) != 0) {
                
                      // Clear MAX_RT bit in status register
                      status_temp = SPI_Send_command_with_ADDR(W_REGISTER, STATUS_ADDR, (status|MAX_RT));
                
                      // No communication event here
                      // ....
                    }
                
                    // If packet sent on TX
                    if ((status & TX_DS) != 0) {
                
                      // Clear TX_DS bit in status register
                      status_temp = SPI_Send_command_with_ADDR(W_REGISTER, STATUS_ADDR, (status|TX_DS));
                
                      // Your code here
                      // ...
                    }
                
                
                    // If TX full
                    if ((status & TX_FULL) != 0)  {
                
                      // Flush TX FIFO (in TX mode)
                      status_temp = SPI_Send_command_without_ADDR(FLUSH_TX, NOP);
                
                      // Your code here
                      // ...
                    }
                
                    // End send one byte -> joystick posotion byte ---------------------------------------------
                
                     // Setting for RX device
                    //Write CONFIG register -> 00001010 - CRC enable, power-up, RX
                    status = SPI_Send_command_with_ADDR(W_REGISTER,CONFIG_REG_ADDR, 0x0B);
                
                    // button was pressed - set flag
                    flag=1;
           }

  //*************************************************************************
  
    // Clear if WAKEUP button is not pressed and byte is send
    if (((BUT2)!=Bit_SET) && (flag !=0))
                    {
                  
                      // Just simple delay
                      Delay_(BUT_TIME);
                  
                      // clear button flag
                      flag = 0;
                    }
     
  
 
  // Chip enable high
  CE_HIGH();

  // wait for receive signal - IRQ
  if ((IRQ)==0) {

                    //Read STATUS status register
                    status = SPI_Send_command_without_ADDR(NOP, NOP);
                
                    // Set high when new data arrives RX FIFO
                    if ((status & RX_DR) != 0) 
                    {
                
                      // Chip enable low
                      CE_LOW();
                
                      //Read payload data
                      payload=SPI_Send_command_without_ADDR(R_RX_PAYLOAD, NOP);
                
                      // Clear RX_DR bit in status register
                      status_temp = SPI_Send_command_with_ADDR(W_REGISTER, STATUS_ADDR, (status|RX_DR));
                    }
      
                  // Check received data
                    if (payload == 0x01)  {
                      // Clear data
                      payload = 0;
                      // LCD init
                      LCDInit();
                      LCDContrast(0x45);
                      LCDClear();
                      LCDStr ( 0, " KEY UP   ", 0 );
                      LCDUpdate();
                    }//if payload
                      
                    if (payload == 0x02)  {
                      // Clear data
                      payload = 0;
                      // LCD init
                      LCDInit();
                      LCDContrast(0x45);
                      LCDClear();
                      LCDStr ( 0, " KEY DOWN   ", 0 );
                      LCDUpdate();
                      }//if payload
      
                     if (payload == 0x03)  {
                      // Clear data
                      payload = 0;
                      // LCD init
                      LCDInit();
                      LCDContrast(0x45);
                      LCDClear();
                      LCDStr ( 0, " KEY LEFT   ", 0 );
                      LCDUpdate();
                   }//if payload
                 
                    if (payload == 0x04)  {
                      // Clear data
                      payload = 0;
                      // LCD init
                      LCDInit();
                      LCDContrast(0x45);
                      LCDClear();
                      LCDStr ( 0, " KEY RIGHT", 0 );
                      LCDUpdate();
                   }//if payload
                    
                    if (payload == 0x05)  {
                      // Clear data
                      payload = 0;
                      // LCD init
                      LCDInit();
                      LCDContrast(0x45);
                      LCDClear();
                      LCDStr ( 0, " KEY CENTER   ", 0 );
                      LCDUpdate();
                   }//if payload
      
          }
   
}

}

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
